@@ -2452,7 +2452,7 @@ expand_path_input (const char *input)
 	char *uri;
 	char *path;
 
-	uri = gnome_vfs_make_uri_from_input (input);
+	uri = gnome_vfs_make_uri_from_input_with_dirs (input, GNOME_VFS_MAKE_URI_DIR_CURRENT);
 	if (uri == NULL) {
 		g_warning ("Could not parse filename");
 		return NULL;
